@@ -1,5 +1,10 @@
 
 .averageBySpecies<-function(OM, spnames) {
+  if(ncol(OM)>1) OM = t(apply(OM,1, tapply, spnames, mean, na.rm=T))
+  else colnames(OM) = spnames[1]
+  return(OM)
+}
+.sumBySpecies<-function(OM, spnames) {
   if(ncol(OM)>1) OM = t(apply(OM,1, tapply, spnames, sum, na.rm=T))
   else colnames(OM) = spnames[1]
   return(OM)
@@ -14,9 +19,19 @@
   else colnames(OM) = spnames[1]
   return(OM)
 }
+.temporalSummary<-function(OM, summary.freq, FUN = mean, ...) {
+  varnames = colnames(OM)
+  date.factor = cut(as.Date(rownames(OM)), breaks=summary.freq)
+  df = data.frame(row.names = as.Date(as.character(levels(date.factor))))
+  for(i in 1:length(varnames)) {
+    df[[varnames[i]]] = tapply(OM[,i],INDEX=date.factor, FUN=FUN, ...)
+  }
+  return(as.matrix(df))
+}
 plot.spwb<-function(x, type="PET_Precipitation", cohorts = NULL, bySpecies = FALSE,
                     dates = NULL, subdaily = FALSE, 
-                    xlim = NULL, ylim=NULL, xlab=NULL, ylab=NULL,...) {
+                    xlim = NULL, ylim=NULL, xlab=NULL, ylab=NULL, 
+                    summary.freq = NULL, ...) {
   
   if(subdaily) return(.plotsubdaily(x,type, cohorts, bySpecies, dates, 
                                     xlim, ylim, xlab, ylab))
@@ -49,13 +64,17 @@ plot.spwb<-function(x, type="PET_Precipitation", cohorts = NULL, bySpecies = FAL
     df[["Snow"]] = WaterBalance$Snow
     df[["Date"]] = as.Date(row.names(WaterBalance))
     if(!is.null(dates)) df = df[df$Date %in% dates,]
-    Date = df$Date
-    Snow = df$Snow
-    Precipitation = df$Precipitation
+    if(!is.null(summary.freq)) {
+      date.factor = cut(as.Date(df$Date), breaks=summary.freq)
+      df = data.frame(Date = as.Date(as.character(levels(date.factor))),
+                      Precipitation = tapply(df$Precipitation,INDEX=date.factor, FUN=sum, na.rm=TRUE),
+                      Snow = tapply(df$Snow,INDEX=date.factor, FUN=sum, na.rm=TRUE),
+                      PET = tapply(df$PET,INDEX=date.factor, FUN=sum, na.rm=TRUE))
+    }
     g<-ggplot(df)+
-      geom_area(aes(x=Date, y=Precipitation, fill="Precipitation"))+
-      geom_area(aes(x=Date, y=Snow, fill="Snow"))+
-      geom_path(aes(x=Date, y=PET, col="PET"))+
+      geom_area(aes_string(x="Date", y="Precipitation", fill='"Precipitation"'))+
+      geom_area(aes_string(x="Date", y="Snow", fill='"Snow"'))+
+      geom_path(aes_string(x="Date", y="PET", col='"PET"'))+
       scale_fill_manual(name="", values=c("Precipitation"="black", "Snow"="red"))+
       scale_color_manual(name="", values=c("PET"="gray"))+
       ylab(ylab)+ xlab(xlab)+
@@ -69,12 +88,15 @@ plot.spwb<-function(x, type="PET_Precipitation", cohorts = NULL, bySpecies = FAL
     df[["NetRain"]] = WaterBalance$NetRain
     df[["Date"]] = as.Date(row.names(WaterBalance))
     if(!is.null(dates)) df = df[df$Date %in% dates,]
-    Date = df$Date
-    PET = df$PET
-    NetRain = df$NetRain
+    if(!is.null(summary.freq)) {
+      date.factor = cut(as.Date(df$Date), breaks=summary.freq)
+      df = data.frame(Date = as.Date(as.character(levels(date.factor))),
+                      NetRain = tapply(df$NetRain,INDEX=date.factor, FUN=sum, na.rm=TRUE),
+                      PET = tapply(df$PET,INDEX=date.factor, FUN=sum, na.rm=TRUE))
+    }
     g<-ggplot(df)+
-      geom_area( aes(x=Date, y=NetRain, fill="NetRain"))+
-      geom_path(aes(x=Date, y=PET, col="PET"))+
+      geom_area(aes_string(x="Date", y="NetRain", fill='"NetRain"'))+
+      geom_path(aes_string(x="Date", y="PET", col='"PET"'))+
       scale_fill_manual(name="", values=c("NetRain"="black"))+
       scale_color_manual(name="", values=c("PET"="gray"))+
       ylab(ylab)+xlab(xlab)+
@@ -88,12 +110,15 @@ plot.spwb<-function(x, type="PET_Precipitation", cohorts = NULL, bySpecies = FAL
     df[["Snowpack"]] = Soil$SWE
     df[["Date"]] = as.Date(row.names(WaterBalance))
     if(!is.null(dates)) df = df[df$Date %in% dates,]
-    Date = df$Date
-    Snow = df$Swow
-    Snowpack = df$Snowpack
+    if(!is.null(summary.freq)) {
+      date.factor = cut(as.Date(df$Date), breaks=summary.freq)
+      df = data.frame(Date = as.Date(as.character(levels(date.factor))),
+                      Snow = tapply(df$Snow,INDEX=date.factor, FUN=sum, na.rm=TRUE),
+                      Snowpack = tapply(df$Snowpack,INDEX=date.factor, FUN=mean, na.rm=TRUE))
+    }
     g<-ggplot(df)+
-      geom_area( aes(x=Date, y=Snow, fill="Snow"))+
-      geom_path(aes(x=Date, y=Snowpack, col="Snowpack"))+
+      geom_area(aes_string(x="Date", y="Snow", fill='"Snow"'))+
+      geom_path(aes_string(x="Date", y="Snowpack", col='"Snowpack"'))+
       scale_fill_manual(name="", values=c("Snow"="black"))+
       scale_color_manual(name="", values=c("Snowpack"="gray"))+
       ylab(ylab)+xlab(xlab)+
@@ -108,13 +133,26 @@ plot.spwb<-function(x, type="PET_Precipitation", cohorts = NULL, bySpecies = FAL
     df[["Plant transpiration"]] = WaterBalance$Transpiration
     df[["Bare soil evaporation"]] = WaterBalance$SoilEvaporation
     if(!is.null(dates)) df = df[row.names(df) %in% as.character(dates),]
+    if(!is.null(summary.freq)) {
+      date.factor = cut(as.Date(row.names(df)), breaks=summary.freq)
+      df = data.frame(row.names = as.Date(as.character(levels(date.factor))),
+                      "Total evapotranspiration" = tapply(df[["Total evapotranspiration"]],INDEX=date.factor, FUN=sum, na.rm=TRUE),
+                      "Interception evaporation" = tapply(df[["Interception evaporation"]],INDEX=date.factor, FUN=sum, na.rm=TRUE),
+                      "Plant transpiration" = tapply(df[["Plant transpiration"]],INDEX=date.factor, FUN=sum, na.rm=TRUE),
+                      "Bare soil evaporation" = tapply(df[["Bare soil evaporation"]],INDEX=date.factor, FUN=sum, na.rm=TRUE))
+    }
     return(.multiple_dynamics(as.matrix(df), ylab=ylab, xlab=xlab, ylim = ylim))
   } 
   else if(type=="WTD") {
     if(is.null(ylab)) ylab = expression(paste("Water table depth  (mm)"))
     xv = Soil$WTD
     names(xv) = row.names(Soil)
-    if(!is.null(dates)) df = df[row.names(df) %in% as.character(dates),]
+    if(!is.null(dates)) xv = xv[names(xv) %in% as.character(dates)]
+    if(!is.null(summary.freq)) {
+      date.factor = cut(as.Date(names(xv)), breaks=summary.freq)
+      xv = tapply(xv,INDEX=date.factor, FUN=mean, na.rm=TRUE)
+      names(xv) = as.character(levels(date.factor))
+    }      
     return(.single_dynamics(xv, ylab = ylab, ylim = ylim))
   } 
   else if(type=="Export") {
@@ -125,14 +163,17 @@ plot.spwb<-function(x, type="PET_Precipitation", cohorts = NULL, bySpecies = FAL
     df[["Runoff"]] = WaterBalance$Runoff 
     df[["Date"]]= as.Date(row.names(WaterBalance))
     if(!is.null(dates)) df = df[df$Date %in% dates,]
-    Date = df$Date
-    Export = df$Export
-    DeepDrainage = df$DeepDrainage
-    Runoff = df$Runoff
+    if(!is.null(summary.freq)) {
+      date.factor = cut(as.Date(df$Date), breaks=summary.freq)
+      df = data.frame(Date = as.Date(as.character(levels(date.factor))),
+                      Export = tapply(df$Export,INDEX=date.factor, FUN=sum, na.rm=TRUE),
+                      DeepDrainage = tapply(df$DeepDrainage,INDEX=date.factor, FUN=sum, na.rm=TRUE),
+                      Runoff = tapply(df$Runoff,INDEX=date.factor, FUN=sum, na.rm=TRUE))
+    }
     g<-ggplot(df)+
-      geom_line( aes(x=Date, y=Export, col="Export"))+
-      geom_line( aes(x=Date, y=DeepDrainage, col="Deep drainage"))+
-      geom_line( aes(x=Date, y=Runoff, col="Runoff"))+
+      geom_line(aes_string(x="Date", y="Export", col='"Export"'))+
+      geom_line(aes_string(x="Date", y="DeepDrainage", col='"Deep drainage"'))+
+      geom_line(aes_string(x="Date", y="Runoff", col='"Runoff"'))+
       scale_color_manual(name="", values=c("Export"="black", "Deep drainage" = "blue", "Runoff" = "red"))+
       ylab(ylab)+ xlab(xlab)+
       theme_bw()
@@ -143,18 +184,21 @@ plot.spwb<-function(x, type="PET_Precipitation", cohorts = NULL, bySpecies = FAL
     MLM = data.frame("Total" = Soil$MLTot, 
                      Soil[,paste("ML",1:nlayers,sep=".")])
     if(!is.null(dates)) MLM = MLM[row.names(MLM) %in% as.character(dates),]
+    if(!is.null(summary.freq)) MLM = .temporalSummary(MLM, summary.freq, mean, na.rm=TRUE)
     return(.multiple_dynamics(as.matrix(MLM), ylab = ylab, ylim = ylim,
                               xlab=xlab, labels = c("Total", paste("Layer", 1:nlayers))))
   } 
   else {
     plot.pwb(x, type=type, cohorts = cohorts, bySpecies = bySpecies,
-             dates = dates, xlim = xlim, ylim=ylim, xlab=xlab, ylab=ylab, ...)
+             dates = dates, xlim = xlim, ylim=ylim, xlab=xlab, ylab=ylab, 
+             summary.freq = summary.freq, ...)
   }
 }
 
 plot.pwb<-function(x, type="PlantTranspiration", cohorts = NULL, bySpecies = FALSE,
                    dates = NULL, subdaily = FALSE,
-                   xlim = NULL, ylim=NULL, xlab=NULL, ylab=NULL, ...) {
+                   xlim = NULL, ylim=NULL, xlab=NULL, ylab=NULL, 
+                   summary.freq = NULL,...) {
   
   if(subdaily) return(.plotsubdaily(x,type, cohorts, bySpecies, dates, 
                                     xlim, ylim, xlab, ylab))
@@ -188,6 +232,7 @@ plot.pwb<-function(x, type="PlantTranspiration", cohorts = NULL, bySpecies = FAL
     PsiM = Soil[,paste("psi",1:nlayers,sep=".")]
     if(is.null(ylab)) ylab = "Soil water potential (MPa)"    
     if(!is.null(dates)) PsiM = PsiM[row.names(PsiM) %in% as.character(dates),]
+    if(!is.null(summary.freq)) PsiM = .temporalSummary(PsiM, summary.freq, mean, na.rm=TRUE)
     return(.multiple_dynamics(as.matrix(PsiM),  xlab = xlab, ylab = ylab, ylim = ylim,
                               labels = paste("Layer", 1:nlayers)))
   } 
@@ -196,6 +241,7 @@ plot.pwb<-function(x, type="PlantTranspiration", cohorts = NULL, bySpecies = FAL
     if(!is.null(dates)) WM = WM[row.names(WM) %in% as.character(dates),]
     theta_FC = soil_thetaFC(input$soil, model = input$control$soilFunctions)
     WM = 100*sweep(WM, 2,theta_FC, "*")
+    if(!is.null(summary.freq)) WM = .temporalSummary(WM, summary.freq, mean, na.rm=TRUE)
     if(is.null(ylab)) ylab = "Soil moisture (% volume)"
     return(.multiple_dynamics(as.matrix(WM),  xlab = xlab, ylab = ylab, ylim = ylim,
                               labels = paste("Layer", 1:nlayers)))
@@ -203,6 +249,7 @@ plot.pwb<-function(x, type="PlantTranspiration", cohorts = NULL, bySpecies = FAL
   else if(type=="SoilRWC") {
     WM = Soil[,paste("W",1:nlayers,sep=".")]
     if(!is.null(dates)) WM = WM[row.names(WM) %in% as.character(dates),]
+    if(!is.null(summary.freq)) WM = .temporalSummary(WM, summary.freq, mean, na.rm=TRUE)
     if(is.null(ylab)) ylab = "Soil moisture (% field capacity)"
     return(.multiple_dynamics(as.matrix(WM),  xlab = xlab, ylab = ylab, ylim = ylim,
                               labels = paste("Layer", 1:nlayers)))
@@ -212,12 +259,14 @@ plot.pwb<-function(x, type="PlantTranspiration", cohorts = NULL, bySpecies = FAL
     df = Stand[,c("LAI", "LAIexpanded", "LAIdead")]
     names(df)<-c("Total (live+dead)", "Live unfolded","Dead standing")
     if(!is.null(dates)) df = df[row.names(df) %in% as.character(dates),]
+    if(!is.null(summary.freq)) df = .temporalSummary(df, summary.freq, mean, na.rm=TRUE)
     return(.multiple_dynamics(as.matrix(df), ylab = ylab, ylim = ylim))
   } 
   else if(type=="PlantExtraction") {
     extrBal = Soil[,paste("PlantExt",1:nlayers,sep=".")]
     if(!is.null(dates)) extrBal = extrBal[row.names(extrBal) %in% as.character(dates),]
     if(is.null(ylab)) ylab = "Extraction from soil layer (mm)"    
+    if(!is.null(summary.freq)) extrBal = .temporalSummary(extrBal, summary.freq, sum, na.rm=TRUE)
     g<-.multiple_dynamics(as.matrix(extrBal),  xlab = xlab, ylab = ylab, ylim = ylim,
                               labels = paste("Layer", 1:nlayers))
     g<-g+geom_abline(slope=0, intercept=0, col="gray")
@@ -227,13 +276,15 @@ plot.pwb<-function(x, type="PlantTranspiration", cohorts = NULL, bySpecies = FAL
     hydrIn = Soil[,paste("HydraulicInput",1:nlayers,sep=".")]
     if(!is.null(dates)) hydrIn = hydrIn[row.names(hydrIn) %in% as.character(dates),]
     if(is.null(ylab)) ylab = "Hydraulic input (mm)"    
+    if(!is.null(summary.freq)) hydrIn = .temporalSummary(hydrIn, summary.freq, sum, na.rm=TRUE)
     return(.multiple_dynamics(as.matrix(hydrIn),  xlab = xlab, ylab = ylab, ylim = ylim,
                               labels = paste("Layer", 1:nlayers)))
   } 
   else if(type=="PlantLAI") {
     OM = PlantsLAI
-    if(bySpecies) OM = .averageBySpecies(OM, spnames)
+    if(bySpecies) OM = .sumBySpecies(OM, spnames)
     if(!is.null(dates)) OM = OM[row.names(OM) %in% as.character(dates),]
+    if(!is.null(summary.freq)) OM = .temporalSummary(OM, summary.freq, mean, na.rm=TRUE)
     if(is.null(ylab)) ylab = expression(paste("Leaf Area Index   ",(m^{2}%.%m^{-2})))
     return(.multiple_dynamics(as.matrix(OM),  xlab = xlab, ylab = ylab, ylim = ylim))
   } 
@@ -241,6 +292,7 @@ plot.pwb<-function(x, type="PlantTranspiration", cohorts = NULL, bySpecies = FAL
     OM = Plants$dEdP[,cohorts,drop=FALSE]
     if(bySpecies) OM = .averageByLAISpecies(OM, PlantsLAI, spnames)
     if(!is.null(dates)) OM = OM[row.names(OM) %in% as.character(dates),]
+    if(!is.null(summary.freq)) OM = .temporalSummary(OM, summary.freq, mean, na.rm=TRUE)
     if(is.null(ylab)) ylab = expression(paste("Average soil-plant conductance ",(mmol%.%m^{-2}%.%s^{-1})))
     return(.multiple_dynamics(as.matrix(OM),  xlab = xlab, ylab = ylab, ylim = ylim))
   } 
@@ -248,6 +300,7 @@ plot.pwb<-function(x, type="PlantTranspiration", cohorts = NULL, bySpecies = FAL
     OM = Plants[[type]][,cohorts,drop=FALSE]*100
     if(bySpecies) OM = .averageByLAISpecies(OM, PlantsLAI, spnames)
     if(!is.null(dates)) OM = OM[row.names(OM) %in% as.character(dates),]
+    if(!is.null(summary.freq)) OM = .temporalSummary(OM, summary.freq, mean, na.rm=TRUE)
     if(is.null(ylab)) ylab = .getYLab(type)
     return(.multiple_dynamics(as.matrix(OM),  xlab = xlab, ylab = ylab, ylim = ylim))
   } 
@@ -255,6 +308,7 @@ plot.pwb<-function(x, type="PlantTranspiration", cohorts = NULL, bySpecies = FAL
     OM = Plants[[type]][,cohorts,drop=FALSE]
     if(bySpecies) OM = .averageByLAISpecies(OM, PlantsLAI, spnames)
     if(!is.null(dates)) OM = OM[row.names(OM) %in% as.character(dates),]
+    if(!is.null(summary.freq)) OM = .temporalSummary(OM, summary.freq, mean, na.rm=TRUE)
     if(is.null(ylab)) ylab = .getYLab(type)
     return(.multiple_dynamics(as.matrix(OM),  xlab = xlab, ylab = ylab, ylim = ylim))
   } 
@@ -269,6 +323,10 @@ plot.pwb<-function(x, type="PlantTranspiration", cohorts = NULL, bySpecies = FAL
       OM1 = OM1[row.names(OM1) %in% as.character(dates),]
       OM2 = OM2[row.names(OM2) %in% as.character(dates),]
     }
+    if(!is.null(summary.freq)) {
+      OM1 = .temporalSummary(OM1, summary.freq, mean, na.rm=TRUE)
+      OM2 = .temporalSummary(OM2, summary.freq, mean, na.rm=TRUE)
+    }
     return(.multiple_dynamics_range(as.matrix(OM1), as.matrix(OM2),  xlab = xlab, ylab = ylab, ylim = ylim))
   }
   else if(type %in% c("LeafPsiMin_SL", "LeafPsiMax_SL", "GSWMin_SL", "GSWMax_SL", "TempMin_SL", "TempMax_SL")) {
@@ -276,6 +334,7 @@ plot.pwb<-function(x, type="PlantTranspiration", cohorts = NULL, bySpecies = FAL
     OM = SunlitLeaves[[subType]][,cohorts,drop=FALSE]
     if(bySpecies) OM = .averageByLAISpecies(OM, PlantsLAI, spnames)
     if(!is.null(dates)) OM = OM[row.names(OM) %in% as.character(dates),]
+    if(!is.null(summary.freq)) OM = .temporalSummary(OM, summary.freq, mean, na.rm=TRUE)
     if(is.null(ylab)) ylab = .getYLab(type)
     return(.multiple_dynamics(as.matrix(OM),  xlab = xlab, ylab = ylab, ylim = ylim))
   } 
@@ -284,6 +343,7 @@ plot.pwb<-function(x, type="PlantTranspiration", cohorts = NULL, bySpecies = FAL
     OM = ShadeLeaves[[subType]][,cohorts,drop=FALSE]
     if(bySpecies) OM = .averageByLAISpecies(OM, PlantsLAI, spnames)
     if(!is.null(dates)) OM = OM[row.names(OM) %in% as.character(dates),]
+    if(!is.null(summary.freq)) OM = .temporalSummary(OM, summary.freq, mean, na.rm=TRUE)
     if(is.null(ylab)) ylab = .getYLab(type)
     return(.multiple_dynamics(as.matrix(OM),  xlab = xlab, ylab = ylab, ylim = ylim))
   } 
@@ -291,15 +351,17 @@ plot.pwb<-function(x, type="PlantTranspiration", cohorts = NULL, bySpecies = FAL
                       "PlantAbsorbedSWR","PlantNetLWR")) {
     subtype = substr(type,6,nchar(type))
     OM = Plants[[subtype]][,cohorts,drop=FALSE]
-    if(bySpecies) OM = .averageBySpecies(OM, spnames)
+    if(bySpecies) OM = .sumBySpecies(OM, spnames)
     if(!is.null(dates)) OM = OM[row.names(OM) %in% as.character(dates),]
+    if(!is.null(summary.freq)) OM = .temporalSummary(OM, summary.freq, mean, na.rm=TRUE)
     if(is.null(ylab)) ylab = .getYLab(type)
     return(.multiple_dynamics(as.matrix(OM),  xlab = xlab, ylab = ylab, ylim = ylim))
   } 
   else if(type=="PlantWaterBalance") {
     OM = Plants$PlantWaterBalance[,cohorts,drop=FALSE]
-    if(bySpecies) OM = .averageBySpecies(OM, spnames)
+    if(bySpecies) OM = .averageByLAISpecies(OM, PlantsLAI, spnames)
     if(is.null(ylab)) ylab = expression(paste("Plant water balance   ",(L%.%m^{-2})))
+    if(!is.null(summary.freq)) OM = .temporalSummary(OM, summary.freq, mean, na.rm=TRUE)
     if(!is.null(dates)) OM = OM[row.names(OM) %in% as.character(dates),]
     return(.multiple_dynamics(as.matrix(OM),  xlab = xlab, ylab = ylab, ylim = ylim))
   } 
@@ -311,6 +373,7 @@ plot.pwb<-function(x, type="PlantTranspiration", cohorts = NULL, bySpecies = FAL
     df[PlantsLAI==0] = NA
     if(bySpecies) df = .averageByLAISpecies(df, PlantsLAI, spnames)
     if(!is.null(dates)) df = df[row.names(df) %in% as.character(dates),]
+    if(!is.null(summary.freq)) df = .temporalSummary(df, summary.freq, mean, na.rm=TRUE)
     if(is.null(ylab)) ylab = .getYLab(type)
     return(.multiple_dynamics(as.matrix(df),  xlab = xlab, ylab = ylab, ylim = ylim))
   } 
@@ -318,8 +381,9 @@ plot.pwb<-function(x, type="PlantTranspiration", cohorts = NULL, bySpecies = FAL
     OM = Plants$GrossPhotosynthesis/Plants$Transpiration
     OM[Plants$Transpiration==0] = 0
     OM = OM[,cohorts,drop=FALSE]
-    if(bySpecies) OM = .averageBySpecies(OM, spnames)
+    if(bySpecies) OM = .averageByLAISpecies(OM, PlantsLAI, spnames)
     if(!is.null(dates)) OM = OM[row.names(OM) %in% as.character(dates),]
+    if(!is.null(summary.freq)) OM = .temporalSummary(OM, summary.freq, mean, na.rm=TRUE)
     if(is.null(ylab)) ylab = expression(paste("Plant daily WUE   ",(g*C%.%L^{-1})))
     return(.multiple_dynamics(as.matrix(OM),  xlab = xlab, ylab = ylab, ylim = ylim))
   } 
@@ -330,6 +394,7 @@ plot.pwb<-function(x, type="PlantTranspiration", cohorts = NULL, bySpecies = FAL
     df[["Inside-canopy"]] = x$Temperature$Tcan_mean
     df[["Soil"]] = x$Temperature$Tsoil_mean
     if(!is.null(dates)) df = df[row.names(df) %in% as.character(dates),]
+    if(!is.null(summary.freq)) df = .temporalSummary(df, summary.freq, mean, na.rm=TRUE)
     return(.multiple_dynamics(as.matrix(df),  xlab = xlab, ylab=ylab, ylim = ylim))
   }
   else if(type=="TemperatureRange") {
@@ -346,6 +411,10 @@ plot.pwb<-function(x, type="PlantTranspiration", cohorts = NULL, bySpecies = FAL
       df1 = df1[row.names(df1) %in% as.character(dates),]
       df2 = df2[row.names(df2) %in% as.character(dates),]
     }
+    if(!is.null(summary.freq)) {
+      df1 = .temporalSummary(df1, summary.freq, mean, na.rm=TRUE)
+      df2 = .temporalSummary(df2, summary.freq, mean, na.rm=TRUE)
+    }
     return(.multiple_dynamics_range(as.matrix(df1),  as.matrix(df2), xlab = xlab, ylab=ylab, ylim = ylim))
   }
   else if(type=="AirTemperature") {
@@ -355,6 +424,7 @@ plot.pwb<-function(x, type="PlantTranspiration", cohorts = NULL, bySpecies = FAL
     df[["Minimum"]] = x$Temperature$Tatm_min
     df[["Maximum"]] = x$Temperature$Tatm_max
     if(!is.null(dates)) df = df[row.names(df) %in% as.character(dates),]
+    if(!is.null(summary.freq)) df = .temporalSummary(df, summary.freq, mean, na.rm=TRUE)
     return(.multiple_dynamics(as.matrix(df),  xlab = xlab, ylab=ylab, ylim = ylim))
   } 
   else if(type=="CanopyTemperature") {
@@ -364,6 +434,7 @@ plot.pwb<-function(x, type="PlantTranspiration", cohorts = NULL, bySpecies = FAL
     df[["Minimum"]] = x$Temperature$Tcan_min
     df[["Maximum"]] = x$Temperature$Tcan_max
     if(!is.null(dates)) df = df[row.names(df) %in% as.character(dates),]
+    if(!is.null(summary.freq)) df = .temporalSummary(df, summary.freq, mean, na.rm=TRUE)
     return(.multiple_dynamics(as.matrix(df),  xlab = xlab, ylab=ylab, ylim = ylim))
   } 
   else if(type=="SoilTemperature") {
@@ -373,6 +444,7 @@ plot.pwb<-function(x, type="PlantTranspiration", cohorts = NULL, bySpecies = FAL
     df[["Minimum"]] = x$Temperature$Tsoil_min
     df[["Maximum"]] = x$Temperature$Tsoil_max
     if(!is.null(dates)) df = df[row.names(df) %in% as.character(dates),]
+    if(!is.null(summary.freq)) df = .temporalSummary(df, summary.freq, mean, na.rm=TRUE)
     return(.multiple_dynamics(as.matrix(df),  xlab = xlab, ylab=ylab, ylim = ylim))
   } 
   else if(type=="CanopyEnergyBalance") {
@@ -385,6 +457,7 @@ plot.pwb<-function(x, type="PlantTranspiration", cohorts = NULL, bySpecies = FAL
     df[["Convection can./atm."]] = -x$EnergyBalance$Hcan
     df[["Convection soil/can."]] = -x$EnergyBalance$Hcansoil
     if(!is.null(dates)) df = df[row.names(df) %in% as.character(dates),]
+    if(!is.null(summary.freq)) df = .temporalSummary(df, summary.freq, mean, na.rm=TRUE)
     g<-.multiple_dynamics(as.matrix(df),  xlab = xlab, ylab=ylab, ylim = ylim)
     return(g)
   } 
@@ -397,6 +470,7 @@ plot.pwb<-function(x, type="PlantTranspiration", cohorts = NULL, bySpecies = FAL
     df[["Convection soil/can."]] = x$EnergyBalance$Hcansoil
     df[["Latent heat"]] = -x$EnergyBalance$LEsoil
     if(!is.null(dates)) df = df[row.names(df) %in% as.character(dates),]
+    if(!is.null(summary.freq)) df = .temporalSummary(df, summary.freq, mean, na.rm=TRUE)
     g<-.multiple_dynamics(as.matrix(df),  xlab = xlab, ylab=ylab, ylim = ylim)
     return(g)
     # lines(dates, x$EnergyBalance$Ebalsoil, col="black",...)
@@ -412,7 +486,8 @@ plot.pwb<-function(x, type="PlantTranspiration", cohorts = NULL, bySpecies = FAL
 }
 plot.growth<-function(x, type="PET_Precipitation", cohorts = NULL, bySpecies = FALSE, 
                       dates = NULL, subdaily = FALSE, 
-                      xlim = NULL, ylim=NULL, xlab=NULL, ylab=NULL, ...) {
+                      xlim = NULL, ylim=NULL, xlab=NULL, ylab=NULL, 
+                      summary.freq = NULL, ...) {
   
   if(subdaily) return(.plotsubdaily(x,type, cohorts, bySpecies, dates, 
                                     xlim, ylim, xlab, ylab))
@@ -438,14 +513,17 @@ plot.growth<-function(x, type="PET_Precipitation", cohorts = NULL, bySpecies = F
   PlantsLAI = Plants$LAI[,cohorts, drop=FALSE]
   
   if(type %in% TYPES_SWB) {
-    plot.spwb(x,type, cohorts, bySpecies, dates, subdaily, xlim, ylim, xlab, ylab, ...)
+    plot.spwb(x,type, cohorts, bySpecies, dates, subdaily, xlim, ylim, xlab, ylab, 
+              summary.freq, ...)
   } 
-  else if(type %in% c("GrossPhotosynthesis", "MaintenanceRespiration",  "GrowthCosts", "CarbonBalance", 
+  else if(type %in% c("GrossPhotosynthesis", "MaintenanceRespiration",  "GrowthCosts", 
+                      "CarbonBalance", 
                       "SugarLeaf","StarchLeaf","SugarSapwood","StarchSapwood", "SugarTransport", "RootExudation",
                       "LeafPI0", "StemPI0")) {
       OM = PCB[[type]][,cohorts,drop=FALSE]
-      if(bySpecies) OM = .averageBySpecies(OM, spnames)
+      if(bySpecies) OM = .averageByLAISpecies(OM, PlantsLAI, spnames)
       if(!is.null(dates)) OM = OM[row.names(OM) %in% as.character(dates),]
+      if(!is.null(summary.freq)) OM = .temporalSummary(OM, summary.freq, mean, na.rm=TRUE)
       if(is.null(ylab)) ylab=.getYLab(type)
       return(.multiple_dynamics(as.matrix(OM),  xlab = xlab, ylab = ylab, ylim = ylim))
   } 
@@ -453,39 +531,48 @@ plot.growth<-function(x, type="PET_Precipitation", cohorts = NULL, bySpecies = F
                       "SapwoodBiomass", "LeafBiomass", "FineRootBiomass",
                       "LabileBiomass", "TotalLivingBiomass")) {
     OM = PlantStructure[[type]][,cohorts,drop=FALSE]
-    if(bySpecies) OM = .averageBySpecies(OM, spnames)
+    if(bySpecies) OM = .averageByLAISpecies(OM, PlantsLAI, spnames)
     if(!is.null(dates)) OM = OM[row.names(OM) %in% as.character(dates),]
+    if(!is.null(summary.freq)) OM = .temporalSummary(OM, summary.freq, mean, na.rm=TRUE)
     if(is.null(ylab)) ylab = .getYLab(type)
     return(.multiple_dynamics(as.matrix(OM),  xlab = xlab, ylab = ylab, ylim = ylim))
   } 
   else if(type %in% c("SAgrowth", "LAgrowth", "FRAgrowth")) {
       OM = PlantGrowth[[type]][,cohorts,drop=FALSE]
-      if(bySpecies) OM = .averageBySpecies(OM, spnames)
+      if(bySpecies) OM = .averageByLAISpecies(OM, PlantsLAI, spnames)
       if(!is.null(dates)) OM = OM[row.names(OM) %in% as.character(dates),]
+      if(!is.null(summary.freq)) OM = .temporalSummary(OM, summary.freq, mean, na.rm=TRUE)
       if(is.null(ylab)) ylab = .getYLab(type)
       return(.multiple_dynamics(as.matrix(OM),  xlab = xlab, ylab = ylab, ylim = ylim))
   } 
   else if(type=="HuberValue") {
     OM = PlantStructure[["SapwoodArea"]][,cohorts,drop=FALSE] / PlantStructure[["LeafArea"]][,cohorts,drop=FALSE]
-    if(bySpecies) OM = .averageBySpecies(OM, spnames)
+    if(bySpecies) OM = .averageByLAISpecies(OM, PlantsLAI, spnames)
     if(!is.null(dates)) OM = OM[row.names(OM) %in% as.character(dates),]
+    if(!is.null(summary.freq)) OM = .temporalSummary(OM, summary.freq, mean, na.rm=TRUE)
     if(is.null(ylab)) ylab = .getYLab(type)
     return(.multiple_dynamics(as.matrix(OM),  xlab = xlab, ylab = ylab, ylim = ylim))
   } 
   else if(type=="RootAreaLeafArea") {
     OM = PlantStructure[["FineRootArea"]][,cohorts,drop=FALSE] / PlantStructure[["LeafArea"]][,cohorts,drop=FALSE]
-    if(bySpecies) OM = .averageBySpecies(OM, spnames)
+    if(bySpecies) OM = .averageByLAISpecies(OM, PlantsLAI, spnames)
     if(!is.null(dates)) OM = OM[row.names(OM) %in% as.character(dates),]
+    if(!is.null(summary.freq)) OM = .temporalSummary(OM, summary.freq, mean, na.rm=TRUE)
     if(is.null(ylab)) ylab = .getYLab(type)
     return(.multiple_dynamics(as.matrix(OM),  xlab = xlab, ylab = ylab, ylim = ylim))
   } 
 }
 
-.averageSubdailyBySpecies<-function(OM, spnames) {
+.sumSubdailyBySpecies<-function(OM, spnames) {
   if(ncol(OM)>2) OM = cbind(OM[,1],t(apply(OM[,-1],1, tapply, spnames, sum, na.rm=T)))
   else colnames(OM)[2] = spnames[1]
   return(OM)
 }
+.averageSubdailyBySpecies<-function(OM, spnames) {
+  if(ncol(OM)>2) OM = cbind(OM[,1],t(apply(OM[,-1],1, tapply, spnames, mean, na.rm=T)))
+  else colnames(OM)[2] = spnames[1]
+  return(OM)
+}
 .plotsubdaily<-function(x, type="PlantTranspiration", cohorts = NULL, bySpecies = FALSE,
                         dates = NULL, xlim = NULL, ylim=NULL, xlab=NULL, ylab=NULL) {
   if(("spwb" %in% class(x)) || ("pwb" %in% class(x))) {
@@ -584,8 +671,8 @@ plot.growth<-function(x, type="PET_Precipitation", cohorts = NULL, bySpecies = F
     return(.multiple_dynamics_subdaily_sunlit_shade(mSu, mSh, ylab = ylab, ylim = ylim))
   } 
   else if(type=="LeafStomatalConductance") {
-    mSu = extractSubdaily(x, "SunlitLeaves$GW", dates)[,c("datetime", cohorts), drop=FALSE]
-    mSh = extractSubdaily(x, "ShadeLeaves$GW", dates)[,c("datetime", cohorts), drop=FALSE]
+    mSu = extractSubdaily(x, "SunlitLeaves$Gsw", dates)[,c("datetime", cohorts), drop=FALSE]
+    mSh = extractSubdaily(x, "ShadeLeaves$Gsw", dates)[,c("datetime", cohorts), drop=FALSE]
     if(is.null(ylab)) ylab=expression(paste("Stomatal conductance ", (mol%.%m^{-2}%.%s^{-1})))
     return(.multiple_dynamics_subdaily_sunlit_shade(mSu, mSh, ylab = ylab, ylim = ylim))
   } 
