@@ -25,13 +25,13 @@ double leafStructuralBiomass(double LAI, double N, double SLA);
 double leafStarchCapacity(double LAI, double N, double SLA, double leafDensity);
 
 double sapwoodStorageVolume(double SA, double H, NumericVector L, NumericVector V, 
-                            double woodDensity, double vessel2sapwood);
+                            double woodDensity, double conduit2sapwood);
 double sapwoodStructuralBiomass(double SA, double H, NumericVector L, NumericVector V, 
                                 double woodDensity);
 double sapwoodStructuralLivingBiomass(double SA, double H, NumericVector L, NumericVector V,
-                                      double woodDensity, double vessel2sapwood);
+                                      double woodDensity, double conduit2sapwood);
 double sapwoodStarchCapacity(double SA, double H, NumericVector L, NumericVector V, 
-                             double woodDensity, double vessel2sapwood);
+                             double woodDensity, double conduit2sapwood);
 
 double sugarStarchDynamicsLeaf(double sugarConc, double starchConc, double eqSugarConc);
 double sugarStarchDynamicsStem(double sugarConc, double starchConc, double eqSugarConc);
