@@ -5,6 +5,8 @@
 #endif
 using namespace Rcpp;
 
+CharacterVector layerNames(int nlayers);
+
 double theta2psiSaxton(double clay, double sand, double theta, double om = NA_REAL);
 double psi2thetaSaxton(double clay, double sand, double psi, double om = NA_REAL);
 double theta2psiVanGenuchten(double n, double alpha, double theta_res, double theta_sat, double theta);
@@ -29,7 +31,9 @@ String USDAType(double clay, double sand);
 NumericVector vanGenuchtenParamsCarsel(String soilType);
 NumericVector vanGenuchtenParamsToth(double clay, double sand, double om, double bd, bool topsoil);
   
-List soil(List SoilParams, String VG_PTF = "Carsel", NumericVector W = NumericVector::create(1.0,1.0,1.0));
+List soil(List SoilParams, String VG_PTF = "Carsel", 
+          NumericVector W = NumericVector::create(1.0,1.0,1.0),
+          double SWE = 0.0);
 
 NumericVector layerThermalConductivity(NumericVector sand, NumericVector clay, NumericVector W, NumericVector Theta_FC);
 NumericVector temperatureChange(NumericVector dVec, NumericVector Temp,
