@@ -32,10 +32,10 @@ List spwbDay(List x, CharacterVector date, double tmin, double tmax,
              double rhmin, double rhmax, double rad, double wind, 
              double latitude, double elevation, double slope, double aspect,  
              double prec, double runon=0.0);
-List spwbDay1(List x, double tday, double pet, double prec, double er, double runon=0.0, 
-              double rad = NA_REAL, double elevation = NA_REAL, bool verbose=false);
-List spwbDay2(List x, double tmin, double tmax, double tminPrev, double tmaxPrev, double tminNext, 
-              double rhmin, double rhmax, double rad, double wind, 
+List spwbDay1(List x, NumericVector meteovec, 
+              double elevation = NA_REAL, 
+              double runon=0.0, bool verbose=false);
+List spwbDay2(List x, NumericVector meteovec, 
               double latitude, double elevation, double slope, double aspect,
               double solarConstant, double delta, 
-              double prec, double pet, double er, double runon=0.0, bool verbose = false);
+              double runon=0.0, bool verbose = false);
